@@ -1,10 +1,9 @@
 # vi:fdm=marker fdl=0
-# $Id: StdDev.pm,v 1.8 2004/03/23 13:01:42 jettero Exp $ 
+# $Id: StdDev.pm,v 1.6 2003/12/02 22:03:59 jettero Exp $ 
 
 package Statistics::Basic::StdDev;
 
 use strict;
-no warnings;
 use Carp;
 use Statistics::Basic::Variance;
 
@@ -104,15 +103,6 @@ __END__
 
     A machine to calculate the standard deviation of a given vector.
 
-=head1 ENV VARIABLES
-
-=head2 DEBUG
-
-   Try setting $ENV{DEBUG}=1; or $ENV{DEBUG}=2; to see the internals.
-
-   Also, from your bash prompt you can 'DEBUG=1 perl ./myprog.pl' to
-   enable debugging dynamically.
-
 =head1 AUTHOR
 
     Please contact me with ANY suggestions, no matter how pedantic.
